@@ -24,9 +24,6 @@ def export():
 
 @export.command('export-images')
 @click.argument('hbjson-file')
-@click.option(
-    '--name', '-n', help='Name of image files.', default="Camera", show_default=True
-)
 @click.option(
     '--folder', '-f', help='Path to target folder.',
     type=click.Path(exists=False, file_okay=False, resolve_path=True,
@@ -38,12 +35,12 @@ def export():
     help='choose the type of image file.', show_default=True
 )
 @click.option(
-    '--image-width', '-iw', type=int, default=2500, help='Width of images in pixels.',
-    show_default=True
+    '--image-width', '-iw', type=int, default=0, help='Width of images in pixels.'
+    ' If not set, Radiance default x dimension of view will be used.', show_default=True
 )
 @click.option(
-    '--image-height', '-ih', type=int, default=2000, help='Height of images in pixels.',
-    show_default=True
+    '--image-height', '-ih', type=int, default=0, help='Height of images in pixels.'
+    'If not set, Radiance default y dimension of view will be used.', show_default=True
 )
 @click.option(
     '--background-color', '-bc', type=(int, int, int), default=(255, 255, 255),
@@ -77,10 +74,15 @@ def export():
     ' mount simulation data on HBJSON.', type=click.Path(exists=True), default=None,
     show_default=True
 )
+@click.option(
+    '--validate-data', '-vd', is_flag=True, default=False,
+    help='Validate simulation data before loading on the model. This is recommended'
+    ' when using this command locally.', show_default=True
+)
 def export(
-        hbjson_file, name, folder, image_type, image_width, image_height,
+        hbjson_file, folder, image_type, image_width, image_height,
         background_color, model_display_mode, grid_options, grid_display_mode, view,
-        config):
+        config, validate_data):
     """Export images from radiance views in a HBJSON file.
 
     \b
@@ -145,10 +147,10 @@ def export(
         scene = Scene(background_color=background_color)
         scene.add_actors(actors)
 
-        # Set a default camera if there are not cameras in the model
+        # Set a default camera if there are no cameras in the model
         if not model.cameras and not view:
             actors = Actor.from_model(model=model)
-            camera = Camera(type='l')
+            camera = Camera(identifier='plan', type='l')
             scene.add_cameras(camera)
             bounds = Actor.get_bounds(actors)
             centroid = Actor.get_centroid(actors)
@@ -169,10 +171,13 @@ def export(
 
         # load config if provided
         if config:
-            load_config(config, model, scene)
+            if validate_data:
+                load_config(config, model, scene, validation=True)
+            else:
+                load_config(config, model, scene)
 
         output = scene.export_images(
-            folder=folder, name=name, image_type=image_type,
+            folder=folder, image_type=image_type,
             image_width=image_width, image_height=image_height)
 
     except Exception:
