@@ -2,10 +2,11 @@
 
 from __future__ import annotations
 import json
+import os
 import pathlib
 import warnings
 
-from typing import List, Union, Tuple
+from typing import List, Union, Tuple, TypeVar
 from pydantic import BaseModel, validator, Field, constr, conint
 from pydantic.types import confloat, conlist
 from .types import DataSetNames
@@ -16,6 +17,27 @@ from .vtkjs.schema import DisplayMode
 from .scene import Scene
 
 
+class InputFile(BaseModel):
+    """Config for the input file to be consumed by the config command."""
+    paths: List[str] = Field(
+        description='Paths to the result folders.')
+
+    identifiers: List[str] = Field(
+        description='Identifiers for the simulation data that will be mounted on the'
+        ' model. The length of this list must match the length of paths.')
+
+    units: List[str] = Field(
+        description='Units for the simulation data that will be mounted on the'
+        ' model. The length of this list must match the length of paths.')
+
+    @validator('identifiers', 'units')
+    def check_length(cls, v, values):
+        """Check that the length of identifiers and units match the length of paths."""
+        if len(values['paths']) != len(v):
+            raise ValueError('The length of paths, identifiers, and units must match.')
+        return v
+
+
 class Autocalculate(BaseModel):
 
     type: constr(regex='^Autocalculate$') = 'Autocalculate'
@@ -141,7 +163,7 @@ class LegendConfig(BaseModel):
 
 
 class DataConfig(BaseModel):
-    """Config for simulation results you'd like to load on a honeybee-vtk model."""
+    """data-config for simulation results you'd like to load on a honeybee-vtk model."""
 
     identifier: str = Field(
         description='identifier to be given to data. Example, "Daylight-Factor".'
@@ -175,15 +197,6 @@ class DataConfig(BaseModel):
         description='Legend parameters to create legend out of the this dataset.'
     )
 
-    @validator('path')
-    def validate_folder_path(cls, v: str) -> str:
-        if pathlib.Path(v).is_dir():
-            return v
-        else:
-            raise ValueError(
-                'Not a valid folder path.'
-            )
-
     @validator('legend_parameters')
     def check_pos_against_width_height(cls, v: LegendConfig, values) -> LegendConfig:
         id = values['identifier']
@@ -206,6 +219,14 @@ class DataConfig(BaseModel):
         return v
 
 
+class Config(BaseModel):
+    """Config for simulation results you'd like to load on a honeybee-vtk model."""
+    data: List[DataConfig] = Field(
+        description='List of data-config objects that define the data to be loaded on'
+        ' the model.'
+    )
+
+
 def _get_grid_type(model: Model) -> str:
     """Get the type of grid in the model
 
@@ -299,7 +320,6 @@ def _load_data(folder_path: pathlib.Path, identifier: str, model: Model,
         legend_range: A list of min and max values of the legend parameters provided by
             the user in the config file.
     """
-
     grids_info_json = folder_path.joinpath('grids_info.json')
     with open(grids_info_json) as fh:
         grids_info = json.load(fh)
@@ -341,7 +361,7 @@ def _load_data(folder_path: pathlib.Path, identifier: str, model: Model,
 def _get_legend_range(data: DataConfig) -> List[Union[float, int]]:
     """Read and get legend min and max values from data if provided by the user.
 
-    The value provided by this function is processed and validated in _get_data_range 
+    The value provided by this function is processed and validated in _get_data_range
     function in the type module.
 
     Args:
@@ -428,6 +448,11 @@ def load_config(json_path: str, model: Model, scene: Scene,
     Returns:
         A honeybee-vtk model with data loaded on it.
     """
+    assert len(model.sensor_grids.data) > 0, 'Sensor grids are not loaded on'\
+        ' this model. Reload them using grid options.'
+
+    config_dir = pathlib.Path(json_path).parent
+
     try:
         with open(json_path) as fh:
             config = json.load(fh)
@@ -436,15 +461,19 @@ def load_config(json_path: str, model: Model, scene: Scene,
             'Not a valid json file.'
         )
     else:
-        for json_obj in config.values():
-            # check if model has grids loaded
-            assert len(model.sensor_grids.data) > 0, 'Sensor grids are not loaded on'\
-                ' this model. Reload them using grid options.'
+        for json_obj in config['data']:
             # validate config
             data = DataConfig.parse_obj(json_obj)
-            # if data is requested
+            # only if data is requested move forward.
             if not data.hide:
                 folder_path = pathlib.Path(data.path)
+                if not folder_path.is_dir():
+                    folder_path = config_dir.joinpath(
+                        folder_path).resolve().absolute()
+                    data.path = folder_path.as_posix()
+                    if not folder_path.is_dir():
+                        raise FileNotFoundError(
+                            f'No folder found at {data.path}')
                 identifier = data.identifier
                 grid_type = _get_grid_type(model)
                 # Validate data if asked for
@@ -454,13 +483,10 @@ def load_config(json_path: str, model: Model, scene: Scene,
                 legend_range = _get_legend_range(data)
                 # Load data
                 _load_data(folder_path, identifier, model, grid_type, legend_range)
-                # If legend is requested and legend parameters are provided
-                # Legend will only be used in export-images command
-                if legend and data.legend_parameters:
-                    _load_legend_parameters(data, model, scene, legend_range)
+                # Load legend parameters
+                _load_legend_parameters(data, model, scene, legend_range)
             else:
                 warnings.warn(
                     f'Data for {data.identifier} is not loaded.'
                 )
-
     return model
